JavascriptChannelRegistry class

Utility class for managing named JavaScript channels and forwarding incoming messages on the correct channel.

Constructors

JavascriptChannelRegistry(Set<JavascriptChannel>? channels)
Constructs a JavascriptChannelRegistry initializing it with the given set of JavascriptChannels.

Properties

channels → Map<String, JavascriptChannel>
Maps a channel name to a channel.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onJavascriptChannelMessage(String channel, String message) → void
Invoked when a JavaScript channel message is received.
toString() → String
A string representation of this object.
inherited
updateJavascriptChannelsFromSet(Set<JavascriptChannel>? channels) → void
Updates the set of JavascriptChannels with the new set.

Operators

operator ==(Object other) → bool
The equality operator.
inherited